Use this to anonymize faces and electrophysiology data. Please cite the github repository if you do.

There is absolutely no warrenty that this will correctly remove faces from all video frames or all data from files. You must check all the videos and data to be sure they are anonymized.

Alex Rockhill
Eugene, OR 2020